Module common_types::chain_notify [−][src]
Types pertaining to sending messages and finding routes through the chain. Used mostly by the ChainNotify trait.
Structs
| ChainRoute | A complete chain enacted retracted route. |
| NewBlocks | Used by |
Enums
| ChainMessageType | Messages to broadcast via chain |
| ChainRouteType | Route type to indicate whether it is enacted or retracted. |