Module common_types::engines [−][src]
Engine-specific types.
Modules
| epoch | Epoch verifiers and transitions. |
| machine | State machine types |
| params | Engine-specific parameter types. |
Structs
| VapashExtensions | Vapash-specific extensions. |
| VapashSeal | Vapash/Clique specific seal |
Enums
| ForkChoice | Fork choice. |
| OptimizeFor | Optimize cache for CPU or memory usage |
| Seal | Seal type. |
| SealingState | The type of sealing the engine is currently able to perform. |
Constants
| DEFAULT_BLOCKHASH_CONTRACT | Default EIP-210 contract code. As defined in https://github.com/vaporyco/EIPs/pull/210 |
| MAX_UNCLE_AGE | The number of generations back that uncles can be. |
Type Definitions
| Headers | Type alias for a function we can get headers by hash through. |
| PendingTransitionStore | Type alias for a function we can query pending transitions by block hash through. |