Struct common_types::pruning_info::PruningInfo[][src]

pub struct PruningInfo {
    pub earliest_chain: u64,
    pub earliest_state: u64,
}

Client pruning info. See module-level docs for more details.

Fields

earliest_chain: u64

The first block which everything can be served after.

earliest_state: u64

The first block where state requests may be served.